Internal function to calculate various p-value corrections for use within the plot_obs, plot_predict, and perlrren functions.
pval_correct(
input,
type = c("FDR", "Sidak", "Bonferroni"),
alpha = 0.05,
nbc = NULL
)An object of class 'numeric' with the corrected alpha level.
A vector of class 'numeric' of p-values from the plot_obs, plot_predict, or perlrren function.
Character string specifying which correction for multiple comparisons. Options include a False Discovery Rate p_correct = "FDR", a Sidak correction p_correct = "Sidak", and a Bonferroni correction p_correct = "Bonferroni".
Numeric. The alpha level for significance threshold (default in plot_obs, plot_predict, and perlrren functions is 0.05).
This function provides functionality for multiple testing correction in five ways:
Computes a False Discovery Rate by Benjamini and Hochberg tools:::Rd_expr_doi("10.1111/j.2517-6161.1995.tb02031.x") (p_correct = "FDR") by: 1) sorting the p-values (p_i) of each knot in ascending order (p_1 <= p_2 <= ... <= p_m), 2) starting from p_m find the first p_i for which p_i <= (i/m) * alpha.
Computes a Sidak correction tools:::Rd_expr_doi("10.2307/2283989") (p_correct = "Sidak") by 1 - (1 - alpha) ^ (1 / total number of gridded knots across the estimated surface). The default in the risk function is a resolution of 128 x 128 or n = 16,384 knots and a custom resolution can be specified using the resolution argument within the risk function.
Computes a Bonferroni correction (p_correct = "Bonferroni") by alpha / total number of gridded knots across the estimated surface. The default in the risk function is a resolution of 128 x 128 or n = 16,384 knots and a custom resolution can be specified using the resolution argument within the risk function.